#!/usr/bin/python3.6.8+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2021-01-23
@desc: uid扩展模块的测试文件
"""
from tests.test_setting_reload import Settings
from yzcore.extensions import uid
LONG_ID = 2306877360852435967
TIME_DURATION = 986434592
TIME_STAMP = 1611338096592
ID_DATA = {
    'machine_id': 1023,
    'sequence': 0,
    'time_duration': 986434592,
    'generate_method': 2,
    'mode_type': 0,
    'version': 0
}


def test_generate_uuid():
    _id = uid.generate_uuid()
    assert isinstance(_id, int)
    assert len(str(_id)) == 19
    print(_id)
    global LONG_ID
    LONG_ID = _id
    _id_list = uid.generate_uuid(3)
    assert isinstance(_id_list, list)
    assert len(_id_list) == 3


def test_explain_uuid():
    id_data = uid.explain_uuid(LONG_ID)
    assert isinstance(id_data, dict)
    assert len(id_data) == 6
    assert 'time_duration' in id_data
    global TIME_DURATION, ID_DATA
    TIME_DURATION = id_data['time_duration']
    ID_DATA = id_data
    print(TIME_DURATION)
    print(id_data)


def test_translate_time():
    result = uid.translate2timestamp(TIME_DURATION)
    assert isinstance(result, dict)
    assert len(result) == 2
    global TIME_STAMP
    TIME_STAMP = result['timestamp']
    print(TIME_STAMP)


def test_make_uuid():
    data = {
        'machine': ID_DATA.get('machine_id'),
        'sequence': ID_DATA.get('sequence'),
        'timestamp': TIME_STAMP,
        'method': ID_DATA.get('generate_method'),
        'mtype': ID_DATA.get('mode_type'),
        'version': ID_DATA.get('version')
    }
    _id = uid.make_uuid(**data)
    assert isinstance(_id, int)
    assert len(str(_id)) == 19
    print(_id)
    assert _id == LONG_ID




if __name__ == '__main__':
    test_generate_uuid()
    test_explain_uuid()
    test_translate_time()
    test_make_uuid()



#!/usr/bin/python3.6.8+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2020-8-27
@desc: ...
"""
import json
import hashlib


def data_md5(data) -> str:
    """
    对传入的数据进行MD5

    :param data:
    :return: d41d8cd98f00b204e9800998ecf8427e (空)
    """
    if not isinstance(data, bytes):
        if not isinstance(data, str):
            data = json.dumps(data)
        data = data.encode('utf-8')
    m = hashlib.md5(data)
    return m.hexdigest()




#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth:
@date: 2020-9-13
@desc: ...
"""
from fastapi import FastAPI
from src.settings import settings
from src.apps.myapp import views as hello_views
# from src.app import views as hello_views

# from src.apps import node
app = FastAPI(
    title=settings.PROJECT_NAME, openapi_url=f"{settings.API_V1_STR}/openapi.json"
)

# # Set all CORS enabled origins
# if settings.BACKEND_CORS_ORIGINS:
#     app.add_middleware(
#         CORSMiddleware,
#         allow_origins=[str(origin) for origin in settings.BACKEND_CORS_ORIGINS],
#         allow_credentials=True,
#         allow_methods=["*"],
#         allow_headers=["*"],
#     )

app.include_router(hello_views.router, prefix=settings.API_V1_STR)


if __name__ == "__main__":
    import uvicorn

    uvicorn.run(app, host='0.0.0.0', port=8080)


#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2021/3/12
@desc: ...
"""
import os
import functools
from yzcore.extensions.oss import OssManagerBase, OssRequestError
# from obs import ObsClient, StorageClass, HeadPermission
try:
    import boto3
except:
    boto3 = None


def wrap_request_return_bool(func):
    """"""
    @functools.wraps(func)
    def wrap_func(*args, **kwargs):
        try:
            resp = func(*args, **kwargs)
            if resp['ResponseMetadata']['HTTPStatusCode'] < 300:
                return True
            else:
                return False
        except:
            import traceback
            print(traceback.format_exc())
    return wrap_func


class OssManager(OssManagerBase):
    # acl_type = {
    #     "private": obs.HeadPermission.PRIVATE,
    #     "onlyread": obs.HeadPermission.PUBLIC_READ,
    #     "readwrite": obs.HeadPermission.PUBLIC_READ_WRITE,
    #     "bucket_read": obs.HeadPermission.PUBLIC_READ_DELIVERED,                # 桶公共读，桶内对象公共读。
    #     "bucket_readwrite": obs.HeadPermission.PUBLIC_READ_WRITE_DELIVERED,     # 桶公共读写，桶内对象公共读写。
    #     "owner_full_control": obs.HeadPermission.BUCKET_OWNER_FULL_CONTROL,     # 桶或对象所有者拥有完全控制权限。
    # }
    # # 存储类型
    # storage_cls = {
    #     "standard": obs.StorageClass.STANDARD,              # 标准类型
    #     "ia": obs.StorageClass.WARM,                        # 低频访问类型
    #     # "archive": oss2.BUCKET_STORAGE_CLASS_ARCHIVE,  # 归档类型
    #     "cold_archive": obs.StorageClass.COLD,              # 冷归档类型
    # }
    # 冗余类型
    # redundancy_type = {
    #     "lrs": oss2.BUCKET_DATA_REDUNDANCY_TYPE_LRS,  # 本地冗余
    #     "zrs": oss2.BUCKET_DATA_REDUNDANCY_TYPE_ZRS,  # 同城冗余（跨机房）
    # }

    def __init__(self, *args, **kwargs):
        super(OssManager, self).__init__(*args, **kwargs)
        self.__init()

    def __init(self, *args, **kwargs):
        """"""
        if boto3 is None:
            raise ImportError("'boto3' must be installed to use OssManager")
        # 创建ObsClient实例
        self.client = boto3.client(
            's3',
            # region_name=None,
            # api_version=None,
            # use_ssl=True,
            # verify=None,
            # endpoint_url=None,
            aws_access_key_id=self.access_key_id,
            aws_secret_access_key=self.access_key_secret,
            # aws_session_token=None,
            # config=None
        )
        # self.bucket = self.client.bucketClient(self.bucket_name)

    @wrap_request_return_bool
    def create_bucket(
            self, bucket_name=None, location='cn-south-1'
    ):
        """"""
        if bucket_name is None:
            bucket_name = self.bucket_name
        return self.client.create_bucket(
            ACL='private',  # |'public-read'|'public-read-write'|'authenticated-read',
            Bucket=bucket_name,
            CreateBucketConfiguration={
                'LocationConstraint': 'cn-northwest-1',  # 'cn-north-1'
            },
            # GrantFullControl='string',
            # GrantRead='string',
            # GrantReadACP='string',
            # GrantWrite='string',
            # GrantWriteACP='string',
            # ObjectLockEnabledForBucket=True|False
        )
        # if resp['ResponseMetadata']['HTTPStatusCode'] == 200:
        #     return True

    def list_buckets(self):
        """

        :return: {
            'Buckets': [
                {
                    'Name': 'string',
                    'CreationDate': datetime(2015, 1, 1)
                },
            ],
            'Owner': {
                'DisplayName': 'string',
                'ID': 'string'
            }
        }
        """
        return self.client.list_buckets()

    @wrap_request_return_bool
    def is_exist_bucket(self, bucket_name=None):
        if bucket_name is None:
            bucket_name = self.bucket_name
        return self.client.head_bucket(
            Bucket=bucket_name,
            # ExpectedBucketOwner='string'
        )

    @wrap_request_return_bool
    def delete_bucket(self, bucket_name=None):
        if bucket_name is None:
            bucket_name = self.bucket_name
        return self.client.delete_bucket(
            Bucket=bucket_name,
            # ExpectedBucketOwner='string'
        )

    def get_sign_url(self, key, expire=10):
        res = self.client.createSignedUrl("GET", self.bucket_name, key, expire)
        return res.signedUrl

    def post_sign_url(self, key, expire=10, form_param=None):
        if form_param:
            return self.client.createPostSignature(
                self.bucket_name, key, expire, formParams=form_param)
        else:
            res = self.client.createSignedUrl(
                "PUT", self.bucket_name, key, expire)
            return res.signedUrl

    def download(self, key, local_name=None,
                 is_return_obj=False, progress_callback=None):
        if not local_name:
            local_name = os.path.abspath(
                os.path.join(self.cache_path, key)
            )
        self.make_dir(os.path.dirname(local_name))
        try:
            if is_return_obj:
                with open(local_name, 'wb') as fileobj:
                    self.client.download_fileobj(
                        self.bucket_name, key, fileobj,
                        Callback=progress_callback)
                    return fileobj
            else:
                self.client.download_file(
                    self.bucket_name, key, local_name,
                    Callback=progress_callback)
                return local_name
        except:
            import traceback
            print(traceback.format_exc())

    def get_file_stream(self, key, bucket_name=None):
        return self.client.get_object(
            Bucket=bucket_name if bucket_name else self.bucket_name,
            Key=key,
            # Range='string',
            # IfMatch='string',
            # IfModifiedSince=datetime(2015, 1, 1),
            # IfNoneMatch='string',
            # IfUnmodifiedSince=datetime(2015, 1, 1),
            # ResponseCacheControl='string',
            # ResponseContentDisposition='string',
            # ResponseContentEncoding='string',
            # ResponseContentLanguage='string',
            # ResponseContentType='string',
            # ResponseExpires=datetime(2015, 1, 1),
            # VersionId='string',
            # SSECustomerAlgorithm='string',
            # SSECustomerKey='string',
            # RequestPayer='requester',
            # PartNumber=123,
            # ExpectedBucketOwner='string'
        )

    def upload(self, key=None, filepath=None, content=None):
        if not any((filepath, content)):
            raise ValueError("not any((filepath, content))")
        if key is None and filepath:
            key = filepath.split('/')[-1]
        try:
            if content:
                resp = self.client.upload_fileobj(
                    content, self.bucket_name, key)
            else:
                resp = self.client.upload_file(
                    filepath, self.bucket_name, key)
            print(resp)
            return True, self.get_file_url(filepath, key)
        except:
            import traceback
            print(traceback.format_exc())
            return False, None

    # def get_policy2(self):
    #     # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.generate_presigned_post
    #     return self.client.generate_presigned_post(
    #         Bucket, Key, Fields=None, Conditions=None, ExpiresIn=3600)

    # def close_client(self):
    #     return self.client.close()









#!/usr/bin/python3.6.8+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2020-9-27
@desc: 从 fastapi.encoders 复制过来的模块
"""
from collections import defaultdict
from enum import Enum
from pathlib import PurePath
from types import GeneratorType
from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union

from pydantic import BaseModel
from pydantic.json import ENCODERS_BY_TYPE

SetIntStr = Set[Union[int, str]]
DictIntStrAny = Dict[Union[int, str], Any]


def generate_encoders_by_class_tuples(
    type_encoder_map: Dict[Any, Callable]
) -> Dict[Callable, Tuple]:
    encoders_by_class_tuples: Dict[Callable, Tuple] = defaultdict(tuple)
    for type_, encoder in type_encoder_map.items():
        encoders_by_class_tuples[encoder] += (type_,)
    return encoders_by_class_tuples


encoders_by_class_tuples = generate_encoders_by_class_tuples(ENCODERS_BY_TYPE)


def jsonable_encoder(
    obj: Any,
    include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
    exclude: Optional[Union[SetIntStr, DictIntStrAny]] = None,
    by_alias: bool = True,
    exclude_unset: bool = False,
    exclude_defaults: bool = False,
    exclude_none: bool = False,
    custom_encoder: dict = {},
    sqlalchemy_safe: bool = True,
) -> Any:
    if include is not None and not isinstance(include, set):
        include = set(include)
    if exclude is not None and not isinstance(exclude, set):
        exclude = set(exclude)
    if isinstance(obj, BaseModel):
        encoder = getattr(obj.__config__, "json_encoders", {})
        if custom_encoder:
            encoder.update(custom_encoder)
        obj_dict = obj.dict(
            include=include,
            exclude=exclude,
            by_alias=by_alias,
            exclude_unset=exclude_unset,
            exclude_none=exclude_none,
            exclude_defaults=exclude_defaults,
        )
        if "__root__" in obj_dict:
            obj_dict = obj_dict["__root__"]
        return jsonable_encoder(
            obj_dict,
            exclude_none=exclude_none,
            exclude_defaults=exclude_defaults,
            custom_encoder=encoder,
            sqlalchemy_safe=sqlalchemy_safe,
        )
    if isinstance(obj, Enum):
        return obj.value
    if isinstance(obj, PurePath):
        return str(obj)
    if isinstance(obj, (str, int, float, type(None))):
        return obj
    if isinstance(obj, dict):
        encoded_dict = {}
        for key, value in obj.items():
            if (
                (
                    not sqlalchemy_safe
                    or (not isinstance(key, str))
                    or (not key.startswith("_sa"))
                )
                and (value is not None or not exclude_none)
                and ((include and key in include) or not exclude or key not in exclude)
            ):
                encoded_key = jsonable_encoder(
                    key,
                    by_alias=by_alias,
                    exclude_unset=exclude_unset,
                    exclude_none=exclude_none,
                    custom_encoder=custom_encoder,
                    sqlalchemy_safe=sqlalchemy_safe,
                )
                encoded_value = jsonable_encoder(
                    value,
                    by_alias=by_alias,
                    exclude_unset=exclude_unset,
                    exclude_none=exclude_none,
                    custom_encoder=custom_encoder,
                    sqlalchemy_safe=sqlalchemy_safe,
                )
                encoded_dict[encoded_key] = encoded_value
        return encoded_dict
    if isinstance(obj, (list, set, frozenset, GeneratorType, tuple)):
        encoded_list = []
        for item in obj:
            encoded_list.append(
                jsonable_encoder(
                    item,
                    include=include,
                    exclude=exclude,
                    by_alias=by_alias,
                    exclude_unset=exclude_unset,
                    exclude_defaults=exclude_defaults,
                    exclude_none=exclude_none,
                    custom_encoder=custom_encoder,
                    sqlalchemy_safe=sqlalchemy_safe,
                )
            )
        return encoded_list

    if custom_encoder:
        if type(obj) in custom_encoder:
            return custom_encoder[type(obj)](obj)
        else:
            for encoder_type, encoder in custom_encoder.items():
                if isinstance(obj, encoder_type):
                    return encoder(obj)

    if type(obj) in ENCODERS_BY_TYPE:
        return ENCODERS_BY_TYPE[type(obj)](obj)
    for encoder, classes_tuple in encoders_by_class_tuples.items():
        if isinstance(obj, classes_tuple):
            return encoder(obj)

    errors: List[Exception] = []
    try:
        data = dict(obj)
    except Exception as e:
        errors.append(e)
        try:
            data = vars(obj)
        except Exception as e:
            errors.append(e)
            raise ValueError(errors)
    return jsonable_encoder(
        data,
        by_alias=by_alias,
        exclude_unset=exclude_unset,
        exclude_defaults=exclude_defaults,
        exclude_none=exclude_none,
        custom_encoder=custom_encoder,
        sqlalchemy_safe=sqlalchemy_safe,
    )



#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2020-9-
@desc: ...
"""
import os
import sys


def platform_check():
    msg = ''
    if sys.platform.startswith(('dragonfly', 'freebsd')):
        msg = 'pkg install'
    elif sys.platform == 'win32':
        msg += '#install-imagemagick-on-windows'
    elif sys.platform == 'darwin':
        mac_pkgmgrs = {'brew': 'brew install freetype imagemagick',
                       'port': 'port install imagemagick'}
        for pkgmgr in mac_pkgmgrs:
            with os.popen('which ' + pkgmgr) as f:
                if f.read().strip():
                    msg = mac_pkgmgrs[pkgmgr]
                    break
        else:
            msg += '#install-imagemagick-on-mac'
    elif hasattr(sys.platform, 'linux_distribution'):
        distname, _, __ = sys.platform.linux_distribution()
        distname = (distname or '').lower()
        if distname in ('debian', 'ubuntu'):
            msg = 'apt-get install libmagickwand-dev'
        elif distname in ('fedora', 'centos', 'redhat'):
            msg = 'yum install ImageMagick-devel'
    raise ImportError('MagickWand shared library not found.\n'
                      'You probably had not installed ImageMagick library.\n'
                      'Try to install:\n  ' + msg)



#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2021/3/8
@desc: ...

AccessKeyId         OSSAccessKeyId
file                file
key                 key
policy              policy
signature           Signature
x-obs-acl           x-oss-object-acl
x-obs-grant-read
x-obs-grant-read-acp
x-obs-grant-write-acp
x-obs-grant-full-control
x-obs-storage-class
x-obs-meta-*                                    x-oss-meta-*
x-obs-website-redirect-location
x-obs-server-side-encryption                    x-oss-server-side-encryption
x-obs-server-side-encryption-kms-key-id         x-oss-server-side-encryption-key-id
x-obs-server-side-encryption-customer-algorithm
x-obs-server-side-encryption-customer-key
x-obs-server-side-encryption-customer-key-MD5
x-obs-expires
success_action_redirect         success_action_redirect
success_action_status           success_action_status
                                x-oss-content-type
token                           x-oss-security-token
"""
import os
import json
import hmac
import urllib
import base64
import hashlib
import datetime
from importlib import import_module
from abc import ABCMeta, abstractmethod

IMAGE_FORMAT_SET = [
    'bmp', 'jpg', 'jpeg', 'png', 'tif', 'gif', 'pcx', 'tga',
    'exif', 'fpx', 'svg', 'psd', 'cdr', 'pcd', 'dxf', 'ufo',
    'eps', 'ai', 'raw', 'WMF', 'webp', 'tiff'
]


class OssManagerError(ValueError):
    """"""


class OssRequestError(Exception):
    """"""


class OssManagerBase(metaclass=ABCMeta):
    def __init__(
            self,
            access_key_id,
            access_key_secret,
            bucket_name,
            endpoint=None,
            cname=None,
            cache_path='.',
            expire_time=30,
            **kwargs
    ):
        self.access_key_id = access_key_id
        self.access_key_secret = access_key_secret
        self.bucket_name = bucket_name
        self.endpoint = endpoint

        self.cache_path = cache_path
        self.scheme = kwargs.get("scheme", "https")
        self.image_domain = kwargs.get("image_domain")
        self.asset_domain = kwargs.get("asset_domain")
        self.policy_expire_time = kwargs.get("policy_expire_time", expire_time)

        self.cname = cname

        self.bucket = None

    @abstractmethod
    def create_bucket(self):
        """创建bucket"""

    @abstractmethod
    def list_buckets(self):
        """查询bucket列表"""

    @abstractmethod
    def is_exist_bucket(self, bucket_name=None):
        """判断bucket是否存在"""

    @abstractmethod
    def delete_bucket(self, bucket_name=None):
        """删除bucket"""

    @abstractmethod
    def get_sign_url(self, key, expire=10):
        """生成下载对象的带授权信息的URL"""

    @abstractmethod
    def post_sign_url(self, key, expire=10):
        """生成上传对象的带授权信息的URL"""

    @abstractmethod
    def download(self, *args, **kwargs):
        """"""

    @abstractmethod
    def upload(self, *args, **kwargs):
        """"""

    def _get_policy_encode(self, key, redirect_url):
        expire_time = datetime.datetime.now() + datetime.timedelta(
            seconds=self.policy_expire_time
        )
        policy_dict = dict(
            expiration=expire_time.isoformat() + "Z",
            conditions=[
                # {"acl": "public-read"},
                # {"x-obs-acl": "public-read"},
                # {"x-obs-security-token": "YwkaRTbdY8g7q...."},
                {"bucket": "yzcore"},
                {"success_action_redirect": redirect_url},
                ["starts-with", "$key", key],                         # 指定值开始
                # ["eq", "$success_action_redirect", "public-read"],  # 精确匹配
                # ["content-length-range", 1, 1024*1024*1024]         # 对象大小限制
            ],
        )
        policy = json.dumps(policy_dict).strip().encode()
        return base64.b64encode(policy)

    def get_signature(self, policy_encode):
        """
        获取签名

        :param policy_encode:
        :return:
        """
        h = hmac.new(
            self.access_key_secret.encode("utf-8"), policy_encode, hashlib.sha1
        )
        sign_result = base64.encodebytes(h.digest()).strip()
        return sign_result.decode()

    def get_policy(
            self,
            key,
            redirect_url,
            # callback_data=None,
            # callback_content_type="application/json"
    ):
        """
        授权给第三方上传

        :param key:
        :param redirect_url:
        :return:
        """
        policy_encode = self._get_policy_encode(key, redirect_url)
        sign = self.get_signature(policy_encode)
        return dict(
            key=key,
            accessid=self.access_key_id,
            host=f"{self.scheme}://{self.bucket_name}.{self.endpoint}",
            policy=policy_encode.decode(),
            signature=sign,
            success_action_redirect=redirect_url
            # callback=base64_callback_body.decode(),
        )

    def get_file_url(self, filepath, key):
        if filepath and filepath.split('.')[-1] in IMAGE_FORMAT_SET:
            resource_url = u"//{domain}/{key}".format(
                domain=self.image_domain, key=key)
        else:
            resource_url = u"//{domain}/{key}".format(
                domain=self.asset_domain, key=key)
        return resource_url

    def delete_cache_file(self, filename):
        """删除文件缓存"""
        filepath = os.path.abspath(os.path.join(self.cache_path, filename))
        assert os.path.isfile(filepath), '非文件或文件不存在'
        os.remove(filepath)

    def search_cache_file(self, filename):
        """文件缓存搜索"""
        # 拼接绝对路径
        filepath = os.path.abspath(os.path.join(self.cache_path, filename))
        if os.path.isfile(filepath):
            return filepath
        else:
            return None

    def make_dir(self, dir_path):
        """新建目录"""
        try:
            os.makedirs(dir_path)
        except OSError:
            pass


class OssManagerProxy:
    def __init__(self, oss_type, **kwargs):
        # self.oss_type = oss_type
        self.client = self.select_oss(oss_type, **kwargs)

    def select_oss(self, oss_type, **kwargs):
        _module = import_module(f"yzcore.extensions.oss.{oss_type}")
        return _module.OssManager(**kwargs)

    def __getattr__(self, item):
        return getattr(self.client, item)





#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2020-9-
@desc: ...
"""
# import sys
# from yzrpc.commands import CommandUtility
#
#
# def main():
#     cmd = CommandUtility()
#     cmd.run_from_argv(sys.argv)
#
#
# if __name__ == '__main__':
#     main()

import sys
from yzcore.core.management import execute_from_command_line


def main():
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    main()


#!/usr/bin/env python3.5+
# -*- coding: utf-8 -*-
"""
@auth: cml
@date: 2019-07-10
@desc: 根据应用来分类日志，每个应用下都有六种日志模式：

        级别        数值
        CRITICAL    50
        ERROR       40
        WARNING     30
        INFO        20
        DEBUG       10
        NOTSET      0
"""
import os
import sys

sys.path.append(os.path.dirname(os.pardir))

import re

SYS_ENV = 'win' if re.search('[Ww]in', sys.platform) else 'unix'

import logging
from .config import LOG_PATH, LOGGING_CONFIG
from .handlers import TimedRotatingFileHandlerMP as TRFMP


# from logging.config import dictConfig
# from logging.handlers import TimedRotatingFileHandler


class InitLoggerConfig:
    __instance = {}  # 单例模式存储对象
    __is_init = False  # 防止重复初始化

    def __new__(cls, app_name='default', *args, **kwargs):
        """对于每个app_name单例模式"""
        if app_name not in cls.__instance:
            cls.__instance[app_name] = super().__new__(cls)
        return cls.__instance[app_name]

    def __init__(self, app_name='default',
                 log_config=LOGGING_CONFIG,
                 log_path=LOG_PATH,
                 is_debug=True):
        """初始化logger，通过LOGGING配置logger"""
        if self.__is_init is True:
            return
        self.log_path = log_path
        log_file_dir = os.path.join(self.log_path, app_name)
        print("初始化%s的logger，日志写入：%s 文件夹下" % (app_name, log_file_dir))
        self.__is_init = True
        self.app_name = app_name
        self.is_debug = is_debug
        self.log_config = log_config

        # 日志名和日志等级的映射
        self.log_levels = ['debug', 'info', 'warning', 'error', 'critical']

        # 默认路径为当前项目根目录下的logs/${app_name}
        self.log_cur_path = os.path.join(self.log_path, self.app_name)
        self.mkdir_log_path()
        self.configure_logging()

    def mkdir_log_path(self):
        if not os.path.exists(self.log_cur_path):  # 不存在就创建default目录
            os.makedirs(self.log_cur_path)

    def configure_logging(self):
        # logging.addLevelName(TRACE_LOG_LEVEL, "TRACE")
        if sys.version_info < (3, 7):
            # https://bugs.python.org/issue30520
            import pickle
            import logging

            def __reduce__(self):
                if isinstance(self, logging.RootLogger):
                    return logging.getLogger, ()

                if logging.getLogger(self.name) is not self:
                    raise pickle.PicklingError("logger cannot be pickled")
                return logging.getLogger, (self.name,)

            logging.Logger.__reduce__ = __reduce__

        # 根据app_name动态更新LOGGING_CONFIG配置，为每个app_name创建文件夹，配置handler
        for level in self.log_levels:
            handler_name = '%s_%s' % (self.app_name, level)
            if level == 'debug':
                self.log_config['handlers'][
                    handler_name] = self.get_console_handler_conf()
            else:
                lev_up = level.upper()
                if self.is_debug:
                    # is_debug开启输出到终端
                    console_handler_conf = self.get_console_handler_conf(lev_up)
                    self.log_config['handlers'][
                        handler_name] = console_handler_conf
                else:
                    filename = os.path.join(self.log_cur_path, (level + '.log'))
                    self.log_config['handlers'][
                        handler_name] = self.get_file_handler_conf(
                        filename=filename, level=lev_up)
        # 添加app logger及app_request logger
        logger_name = '%s_logger' % self.app_name
        self.log_config['loggers'][logger_name] = self.get_logger_conf()

        # 将LOGGING_CONFIG中的配置信息更新到logging中
        if self.log_config is not None:
            from logging import config
            if isinstance(self.log_config, dict):
                config.dictConfig(self.log_config)
            else:
                config.fileConfig(self.log_config)
        # dictConfig(LOGGING_CONFIG)

    def get_console_handler_conf(self, level='DEBUG'):
        console_handler_conf = {
            # 定义输出流的类
            "class": "logging.StreamHandler",
            # handler等级，如果实际执行等级高于此等级，则不触发handler
            "level": level,
            # 输出的日志格式
            "formatter": "custom",
            # 流调用系统输出
            "stream": "ext://sys.stdout",
            'filters': ['%s_filter' % (level.lower())]
        }
        return console_handler_conf

    @staticmethod
    def get_file_handler_conf(filename: str, level='INFO'):
        file_handler_conf = {
            "class": f"{TRFMP.__module__}.{TRFMP.__name__}",
            "formatter": "custom",
            # 要写入的文件名
            # 分割单位，D日，H小时，M分钟，W星期，一般是以小时或天为单位
            # 比如文件名为test.log，到凌晨0点的时候会自动分离出test.log.yyyy-mm-dd
            "when": 'D',
            "interval": 1,
            'backupCount': 5,  # 备份份数
            "encoding": "utf8",
        }
        if SYS_ENV == 'win':
            file_handler_conf[
                'class'] = 'logging.handlers.TimedRotatingFileHandler'
        filters = ['%s_filter' % (level.lower())]
        update_dict = {'filename': filename, 'level': level, 'filters': filters}
        file_handler_conf.update(update_dict)
        return file_handler_conf

    def get_email_handler_conf(self):
        """"""

    def get_queue_handler_conf(self):
        """"""

    def get_http_handler_conf(self):
        """"""

    def get_file_rotating_conf(self):
        """文件根据大小切换备份"""

    def get_logger_conf(self):
        """
        logger 配置
        :return:
        """
        logger_conf = {'handlers': [], 'level': "DEBUG", 'propagate': False}
        # 如果只是debug级别logger，只配置打印handler，不会记录到文件中
        logger_conf['handlers'] = [
            '%s_%s' % (self.app_name, level) for level in self.log_levels]
        return logger_conf


# 获取日常logger
def get_logger(app_name: str, is_debug=True):
    InitLoggerConfig(app_name, is_debug=is_debug)
    logger_name = '%s_logger' % app_name
    logger = logging.getLogger(logger_name)
    return logger


if __name__ == '__main__':
    # 单例模式测试
    logger = get_logger('cml_test', is_debug=True)

    logger.error('error log')
    logger.debug('debug log')
    logger.debug('debug log')



#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2021/3/8
@desc: ...
"""
import os
import functools
from yzcore.extensions.oss import OssManagerBase, OssRequestError
# from obs import ObsClient, StorageClass, HeadPermission
try:
    import obs
except:
    obs = None


def wrap_request_return_bool(func):
    """"""
    @functools.wraps(func)
    def wrap_func(*args, **kwargs):
        try:
            resp = func(*args, **kwargs)
            if resp.status < 300:
                return True
            else:
                return False
        except:
            import traceback
            print(traceback.format_exc())
    return wrap_func


class OssManager(OssManagerBase):
    acl_type = {
        "private": obs.HeadPermission.PRIVATE,
        "onlyread": obs.HeadPermission.PUBLIC_READ,
        "readwrite": obs.HeadPermission.PUBLIC_READ_WRITE,
        "bucket_read": obs.HeadPermission.PUBLIC_READ_DELIVERED,                # 桶公共读，桶内对象公共读。
        "bucket_readwrite": obs.HeadPermission.PUBLIC_READ_WRITE_DELIVERED,     # 桶公共读写，桶内对象公共读写。
        "owner_full_control": obs.HeadPermission.BUCKET_OWNER_FULL_CONTROL,     # 桶或对象所有者拥有完全控制权限。
    }
    # 存储类型
    storage_cls = {
        "standard": obs.StorageClass.STANDARD,              # 标准类型
        "ia": obs.StorageClass.WARM,                        # 低频访问类型
        # "archive": oss2.BUCKET_STORAGE_CLASS_ARCHIVE,  # 归档类型
        "cold_archive": obs.StorageClass.COLD,              # 冷归档类型
    }
    # 冗余类型
    # redundancy_type = {
    #     "lrs": oss2.BUCKET_DATA_REDUNDANCY_TYPE_LRS,  # 本地冗余
    #     "zrs": oss2.BUCKET_DATA_REDUNDANCY_TYPE_ZRS,  # 同城冗余（跨机房）
    # }

    def __init__(self, *args, **kwargs):
        super(OssManager, self).__init__(*args, **kwargs)
        self.__init()

    def __init(self, *args, **kwargs):
        """"""
        if obs is None:
            raise ImportError("'esdk-obs-python' must be installed to use OssManager")
        # 创建ObsClient实例
        self.obsClient = obs.ObsClient(
            access_key_id=self.access_key_id,
            secret_access_key=self.access_key_secret,
            server=self.endpoint
        )
        # self.bucket = self.obsClient.bucketClient(self.bucket_name)

    def create_bucket(
            self, bucket_name=None, location='cn-south-1'
    ):
        """"""
        if bucket_name is None:
            bucket_name = self.bucket_name
        resp = self.obsClient.createBucket(bucket_name, location=location)
        if resp.status < 300:
            return True
        else:
            raise OssRequestError(
                f"errorCode: {resp.errorCode}. Message: {resp.errorMessage}.")

    def list_buckets(self):
        resp = self.obsClient.listBuckets(isQueryLocation=True)
        if resp.status < 300:
            return resp.body.buckets
        else:
            raise OssRequestError(
                f"errorCode: {resp.errorCode}. Message: {resp.errorMessage}.")

    @wrap_request_return_bool
    def is_exist_bucket(self, bucket_name=None):
        if bucket_name is None:
            bucket_name = self.bucket_name
        return self.obsClient.headBucket(bucket_name)

    @wrap_request_return_bool
    def delete_bucket(self, bucket_name=None):
        if bucket_name is None:
            bucket_name = self.bucket_name
        return self.obsClient.deleteBucket(bucket_name)

    def get_sign_url(self, key, expire=10):
        res = self.obsClient.createSignedUrl("GET", self.bucket_name, key, expire)
        return res.signedUrl

    def post_sign_url(self, key, expire=10, form_param=None):
        if form_param:
            return self.obsClient.createPostSignature(
                self.bucket_name, key, expire, formParams=form_param)
        else:
            res = self.obsClient.createSignedUrl(
                "PUT", self.bucket_name, key, expire)
            return res.signedUrl

    def download(self, key, local_name=None,
                 is_return_obj=False, progress_callback=None):
        if not local_name:
            local_name = os.path.abspath(
                os.path.join(self.cache_path, key)
            )
        self.make_dir(os.path.dirname(local_name))
        try:
            resp = self.obsClient.getObject(
                self.bucket_name, key,
                downloadPath=local_name,
                progressCallback=progress_callback
            )

            if resp.status < 300:
                if is_return_obj:
                    with open(local_name, 'rb') as fileobj:
                        return fileobj
                return resp.body.url  # url: /Users/edz/yz-core/tests/cml
            else:
                print('errorCode:', resp.errorCode)
                print('errorMessage:', resp.errorMessage)
        except:
            import traceback
            print(traceback.format_exc())

    def get_file_stream(self, key, bucket_name=None):
        try:
            resp = self.obsClient.getObject(
                self.bucket_name, key,
                loadStreamInMemory=True,
            )
            if resp.status < 300:
                print('requestId:', resp.requestId)
                # 获取对象内容
                print('size:', resp.body.size)
                return resp.body.buffer
            else:
                print('errorCode:', resp.errorCode)
                print('errorMessage:', resp.errorMessage)
        except:
            import traceback
            print(traceback.format_exc())

    def upload(self, key=None, filepath=None, content=None):
        if not any((filepath, content)):
            raise ValueError("not any((filepath, content))")
        if key is None and filepath:
            key = filepath.split('/')[-1]
        try:
            if content:
                resp = self.obsClient.putContent(
                    self.bucket_name, key, content=content)
            else:
                resp = self.obsClient.putFile(
                    self.bucket_name, key, filepath)
            if resp.status < 300:
                print('requestId:', resp.requestId)
                return True, self.get_file_url(filepath, key)
            else:
                print('errorCode:', resp.errorCode)
                print('errorMessage:', resp.errorMessage)
                return False, None
        except:
            import traceback
            print(traceback.format_exc())

    # def close_client(self):
    #     return self.obsClient.close()









#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth: cml, lxm, zq
@date: 2020-10-23
@desc: ...

        # 当返回的 Json 串不是一个标准的 Json 时，
        # resp.json() 函数可以传递一个函数对 json 进行预处理，
        # 如：resp.json(replace(a, b))，replace()函数表示 a 替换为 b。

        # aiohttp 使用 response.read() 函数处理字节流，使用 with open() 方式保存文件或者图片
        # response.read() 函数可以传递数字参数用于读取多少个字节，如：response.read(3)读取前 3 个字节。

参考：https://github.com/raphaelauv/fastAPI-aiohttp-example
"""
import asyncio
from concurrent import futures
from socket import AF_INET
from typing import TypeVar, Union, Optional, List, Dict, AnyStr

try:
    import json as _json
except (ImportError, ModuleNotFoundError):
    import json as _json

try:
    import aiohttp
    from pydantic import BaseModel, Field
except (ImportError, ModuleNotFoundError):

    AioHttpParams = List[Dict[str, Union[str, int, Dict[str, Union[str, int]]]]]
else:
    class AioHttpParams(BaseModel):
        method: AnyStr
        url: AnyStr
        params: Optional[Dict]
        data: Optional[Dict]
        json_: Optional[Dict] = Field(alias='json')
        headers: Optional[Dict]
        timeout: Optional[int]


RequestParams = TypeVar("RequestParams", bound=AioHttpParams)

SIZE_POOL_AIOHTTP = 100
CONCURRENCY = 100  # 限制并发量为1024


class AioHTTP:
    """
    注意：
    在FastAPI中使用时，在事件处理的勾子中全局设置 AioHTTP 的开启和关闭：
    app = FastAPI(
            on_startup=[AioHTTP.on_startup],
            on_shutdown=[AioHTTP.on_shutdown]
        )
    """
    semaphore: asyncio.Semaphore = asyncio.Semaphore(CONCURRENCY)
    session: aiohttp.ClientSession = None

    # def __init__(self, cookies=None, json_serialize=_json.dumps):
    #     self.session = aiohttp.ClientSession(
    #         cookies=cookies,
    #         json_serialize=json_serialize
    #     )

    @classmethod
    def get_session(cls, cookies=None,
                    json_serialize=_json.dumps) -> aiohttp.ClientSession:
        if cls.session is None or cls.session.closed:
            timeout = aiohttp.ClientTimeout(total=2)
            connector = aiohttp.TCPConnector(
                family=AF_INET,
                limit_per_host=SIZE_POOL_AIOHTTP
            )
            cls.session = aiohttp.ClientSession(
                timeout=timeout,
                connector=connector,
                cookies=cookies,
                json_serialize=json_serialize,
            )
        return cls.session

    @classmethod
    async def get(cls, url, params=None, data=None,
                  json=None, headers=None, timeout=30, **kwargs):
        """异步GET请求"""
        return await cls.fetch(
            'get', url, params, data, json, headers, timeout, **kwargs)

    @classmethod
    async def post(cls, url, params=None, data=None,
                   json=None, headers=None, timeout=30, **kwargs):
        """异步POST请求"""
        return await cls.fetch(
            'post', url, params, data, json, headers, timeout, **kwargs)

    @classmethod
    async def put(cls, url, params=None, data=None,
                  json=None, headers=None, timeout=30, **kwargs):
        """异步PUT请求"""
        return await cls.fetch(
            'put', url, params, data, json, headers, timeout, **kwargs)

    @classmethod
    async def patch(cls, url, params=None, data=None,
                    json=None, headers=None, timeout=30, **kwargs):
        """异步PATCH请求"""
        return await cls.fetch(
            'patch', url, params, data, json, headers, timeout, **kwargs)

    @classmethod
    async def delete(cls, url, params=None, data=None,
                     json=None, headers=None, timeout=30, **kwargs):
        """异步DELETE请求"""
        return await cls.fetch(
            'delete', url, params, data, json, headers, timeout, **kwargs)

    @classmethod
    async def fetch(
            cls, method: str, url: str,
            params=None, data=None, json=None, headers=None, timeout=30,
            is_close_sesion: bool=False, **kwargs
    ):
        """
        公共请求调用方法

        :param method:  请求方法
        :param url:     请求路由
        :param params:  请求参数
        :param data:    请求的Form表单参数
        :param json:    请求的Json参数
        :param headers: 请求头参数
        :param timeout: 超时时间
        :param is_close_sesion: 是否关闭Session
        :return:
        """
        await asyncio.sleep(.1)
        client_session = cls.get_session()
        __request = getattr(client_session, method.lower())
        if params:
            params = {key: str(value) for key, value in params.items() if
                      value is not None}
        async with cls.semaphore:
            try:
                async with __request(
                        url,
                        params=params,
                        data=data,
                        json=json,
                        headers=headers,
                        timeout=timeout,
                        **kwargs
                ) as response:
                    if response.content_type == 'application/json':
                        result = await response.json()
                    elif response.content_type == 'text/plain':
                        result = await response.text()
#                     elif response.content_type == 'application/octet=stream':
#                         result = await response.read()
                    else:
                        result = await response.read()
            except Exception as e:
                import traceback
                traceback.print_exc()
                return {'detail': e}, 500
            else:
                if is_close_sesion:
                    await cls.session.close()
                return result, response.status

    @classmethod
    async def bulk_request(cls, querys: List[RequestParams]):
        """
        异步批量请求

        :param querys:
        [
            {'method': 'get', 'url': 'http://httpbin.org/get', 'params': {'key': 'value{}'.format(1)}},
            {'method': 'get', 'url': 'http://httpbin.org/get', 'params': {'key': 'value{}'.format(2)}},
            {'method': 'get', 'url': 'http://httpbin.org/get', 'params': {'key': 'value{}'.format(3)}},
            {'method': 'get', 'url': 'http://httpbin.org/get', 'params': {'key': 'value{}'.format(4)}},
            {'method': 'get', 'url': 'http://httpbin.org/get', 'params': {'key': 'value{}'.format(5)}},
            {'method': 'post', 'url': 'http://httpbin.org/post', 'json': {'key': 'value{}'.format(6)}},
            {'method': 'post', 'url': 'http://httpbin.org/post', 'json': {'key': 'value{}'.format(7)}},
            {'method': 'post', 'url': 'http://httpbin.org/post', 'json': {'key': 'value{}'.format(8)}},
            {'method': 'post', 'url': 'http://httpbin.org/post', 'json': {'key': 'value{}'.format(9)}},
            {'method': 'post', 'url': 'http://httpbin.org/post', 'json': {'key': 'value{}'.format(10)}},
        ]

        :return:
        """
        tasks = [asyncio.ensure_future(cls.fetch(**kw)) for kw in querys]
        responses = await asyncio.gather(*tasks)
        return responses

    @classmethod
    async def close(cls):
        if cls.session:
            await cls.session.close()

    @classmethod
    async def on_startup(cls):
        cls.get_session()

    @classmethod
    async def on_shutdown(cls):
        await cls.close()


def request(method: str, url: str, params=None, data=None,
                json=None, headers=None, timeout=30):
    # _func = getattr(AioHTTP, method.lower())
    loop = asyncio.get_event_loop()

    result = loop.run_until_complete(
        AioHTTP.fetch(
            method, url, params, data, json, headers, timeout,
            is_close_sesion=True)
    )
    return result


if __name__ == '__main__':
    resp = request('get', 'http://httpbin.org/get')
    print(111, resp)



# coding=utf-8
"""
    接口响应状态码
        1. 错误码的个位值与HTTP状态码的400～409有相关性，只有在被占用的情况下才顺移到下一个。
        2. 系统错误码取值范围500000～599999
        3. 业务错误码取值范围400000~-499999(分段使用)
"""
from enum import Enum, unique

__all__ = ("RegisterCode", "ErrorCode", "TipsCode", "WebsocketCode")

# 状态码注册,请同时添加注释
RegisterCode = [
    # 正常码
    200000,  # 正常,请求处理成功
    # 系统级错误代码
    500000,  # 服务器内部错误，无法完成请求
    500001,  # 服务器不支持请求的功能，无法完成请求
    500002,  # 无效的响应
    500003,  # 由于超载或系统维护，服务器暂时的无法处理客户端的请求
    500004,  # 服务器超时
    500005,  # HTTP协议的版本不支持
    500006,  # 兼容旧代码异常

    # 接口级错误代码
    400000,  # 请求语法或参数有误
    400001,  # 未认证
    400002,  # 
    400003,  # 请求太快
    400004,  # 找不到对象
    400005,  # 请求不允许
    400006,  # 请求不合理
    400007,  # 
    400008,  # 超时
    400009,  # 更新冲突
    400010,  # 资源已不存在


    ## 账号
    400100,  # 账号相关请求错误
    400101,  # 重复登录
    400103,  # 用户登录失败
    400104,  # 账号不存在
    400109,  # 更新信息失败
    400110,  # 手机号码格式不正确
    400111,  # 手机短信验证码错误
    400113,  # 60s内不能重复发送短信
    400118,  # 手机短信发送失败
    400119,  # 手机号码已被注册
    400120,  # email格式不正确
    400121,  # email验证码错误
    400123,  # 60s内不能重复发送邮件
    400126,  # 非邀请邮箱
    400127,  # 已经发送过邀请，请15分钟后再邀请
    400128,  # email发送失败
    400129,  # email已被注册
    400130,  # 
    400140,  # 密码格式不正确
    400141,  # 密码不一致
    400143,  # 密码错误
    400150,  # Token过期或失效

    ## 组织
    400200,  # 组织相关请求错误
    400209,  # 已切换到其他团队，请关闭当前页面
    400211,  # 用户未加入任何组织
    400212,  # 用户已加入该组织
    400213,  # 用户不属于此企业
    400223,  # 组织已存在
    400224,  # 组织不存在
    400229,  # 组织名称已被使用
    400233,  # 成员已存在
    400234,  # 成员不存在
    400239,  # 无法删除默认成员

    ## cms
    400300,  # node相关请求错误
    400301,  # 命名格式错误: 文件夹名字只支持中文, 数字, 字母或中划线, 且在50个字符以内
    400302,  # 命名重复
    400303,  # 文件夹已存在
    400304,  # 文件夹不存在
    400305,  # 最多只能创建四层文件夹
    400306,  # 文件已存在
    400307,  # 文件不存在
    400308,  # 请求超时
    400309,  # 
    400310,  # 标签名字格式错误: 字符长度在1-6内
    400311,  # 标签已存在
    400312,  # 标签不存在
    400313,  # 标签名字不能重复
    400314,  # 
    400320,  # 项目已存在
    400321,  # 项目不存在
    400322,  # 
    400323,  # 
    400324,  # 
    400330,  # 分组----------
    400331,  # 
    400332,  # 
    400340,  # 属性----------
    400341,  # 
    400342,  # 
    400343,  # 
    400380,  # limit超出限制
    400381,  # 搜索字段不存在
    400382,  # 排序字段不存在


    ## 权限
    400400,  # 权限相关请求错误
    400401,  # 权限不足
    400402,  # 权限创建失败
    400403,  # 
    400404,  # 找不到该权限
    400405,  # 
    400408,  # 权限查询超时

    ## editor
    400500,  # 编辑器相关请求错误
    400510,  # 模型名称不能超过50个字符
    400511,  # 模型描述不能超过100个字符
    400512,  # 模型组合不存在
    400513,  # 
    400514,  # 模型不存在
    400515,  # 
    400516,  # 
    400520,  # 材质库类型不存在
    400524,  # 材质不存在
    400525,  # 
    400530,  # 天空盒类型不存在
    400534,  # 天空盒不存在
    400540,  # 模板场景不存在
    400544,  # 场景不存在
    400550,  # 父级渲染对象不存在
    400554,  # 渲染对象不存在
    400560,  # 父级事件组不存在
    400564,  # 组件不存在
    400570,  # 父级资源不存在
    400573,  # 不支持的资源类型
    400574,  # 资源不存在
    400576,  # 资源内容不存在
    400584,  # 事件不存在

    ## 任务
    400600,  # Job相关请求错误
    400604,  # 任务不存在
    400608,  # 任务失败
    400610,  # 调用upload_policy参数有误
    400614,  # 对应upload_policy方法不存在
    400620,  # 调用cloud返回错误
    400630,  # 发布失败

    ## 应用
    400700,  # 应用相关请求错误
    400704,  # 应用不存在
    400710,  # platform不存在
    400720,  # 域名已经存在

    ## 支付
    400800,  # 支付相关请求错误
    
]


@unique
class ErrorCode(Enum):
    # 系统级错误代码
    UserNotLogin = dict(code=-10007, desc="用户尚未登录")
    RequestParamInvalid = dict(code=-10008, desc="参数json内容格式不正确")

    # 接口级错误代码
    UserNameAlreadyExists = dict(code=40001, desc="用户名已被注册")
    MaterialLibTypeNotExists = dict(code=40002, desc="材质库类型不存在")
    AccessPermissionDenied = dict(code=40003, desc="访问权限不足")
    SpaceNotExists = dict(code=40004, desc="空间不存在或已删除")
    FolderNameFormatInvalid = dict(
        code=40005, desc="文件夹名字格式错误: 文件夹名字只支持中文, 数字, 字母或下划线, 且在50个字符以内"
    )
    FolderNameConflict = dict(code=40006, desc="文件夹名字不能重复")
    FolderAlreadyExists = dict(code=40007, desc="文件夹已存在")
    FolderLevelLimited = dict(code=40008, desc="最多只能创建四层文件夹")
    DstDirFolderNotExists = dict(code=40009, desc="目标目录文件夹不存在")
    DirFolderNotExists = dict(code=40010, desc="当前目录文件夹不存在")
    FileNotExists = dict(code=40011, desc="文件不存在")
    FileNameConflict = dict(code=40012, desc="文件名字不能重复")
    FileNameFormatInvalid = dict(code=40013, desc="文件名字格式错误: 长度在1-50之间")
    CategoryTokenInvalid = dict(code=40014, desc="分类设置口令错误")
    CategoryParentPathNotExists = dict(code=40015, desc="分类父路径不存在")
    CategoryFormatInvalid = dict(code=40016, desc="分类名格式无效")
    TagNameFormatInvalid = dict(code=40017, desc="标签名字格式错误: 字符长度在1-6内")
    TagAlreadyExists = dict(code=40018, desc="标签已存在")
    TagNotExists = dict(code=40019, desc="标签不存在")
    TagNameConflict = dict(code=40020, desc="标签名字不能重复")
    TemplateNotExists = dict(code=40021, desc="空间自定义字段模板不存在")
    ModelNotExists = dict(code=40022, desc="模型不存在")
    AppCatalogNotExists = dict(code=40023, desc="目录方案不存在")
    CategoryAlreadyExists = dict(code=40024, desc="分类已存在")
    AppSpaceNotExists = dict(code=40025, desc="空间项目不存在")
    AppSolutionsNotFound = dict(code=40026, desc="app方案不存在")
    ProductionNotFound = dict(code=40027, desc="production不存在")
    PageSizeOverflow = dict(code=40028, desc="limit超出限制")
    CabinetNotFound = dict(code=40029, desc="cabinet不存在")
    OperationPermissionDenied = dict(code=40030, desc="未拥有此权限或操作权限不足")
    InvalidAccessToken = dict(code=40031, desc="invalid access token")
    UserNotFound = dict(code=40032, desc="用户不存在")
    ModelDescLengthOverflow = dict(code=40033, desc="模型描述不能超过100个字符")
    ModelNameLengthOverflow = dict(code=40034, desc="模型名称不能超过50个字符")
    CategoryNotExists = dict(code=40035, desc="分类不存在")
    ModelGroupNotExists = dict(code=40036, desc="模型组合不存在")
    ProductionNotExists = dict(code=40037, desc="production不存在")
    JobNotFound = dict(code=40038, desc="任务不存在")
    JobFailed = dict(code=40039, desc="任务失败")
    MaterialNotFound = dict(code=40040, desc="材质不存在")
    InvalidMobile = dict(code=40041, desc="手机号码格式不正确")
    InvalidOperationType = dict(code=40042, desc="非法操作类型")
    SmsSendFailed = dict(code=40043, desc="短信发送失败")
    CaptchaError = dict(code=40044, desc="验证码错误")
    InvalidUsernameOrPassword = dict(code=40045, desc="请输入正确的账号密码")
    PlatformNotFound = dict(code=40046, desc="platform不存在")
    WechatResponseError = dict(code=40047, desc="微信返回错误")
    SpaceNameAlreadyExists = dict(code=40048, desc="空间名称已被使用")
    InvalidEmail = dict(code=40049, desc="email格式不正确")
    InvalidUploadPolicy = dict(code=40050, desc="对应upload_policy方法不存在")
    InvalidPassword = dict(code=40051, desc="密码格式不正确")
    MobileAlreadyExists = dict(code=40052, desc="手机号码已注册")
    InvalidCabinetName = dict(code=40053, desc="cabinet名称格式不正确")
    CabinetNameAlreadyExisted = dict(code=40054, desc="cabinet名称已被使用")
    InvalidCallback = dict(code=40055, desc="invalid callback token")
    CallCloudError = dict(code=40056, desc="调用cloud返回错误")
    InvalidProductionName = dict(code=40057, desc="非法的产品名称")
    AppHomeCatalogNotExisted = dict(code=40058, desc="未设置首页方案")
    ClientNotFound = dict(code=40059, desc="客户端不存在")
    ClientChannelNotExists = dict(code=40060, desc="客户端渠道不存在")
    HomeSolutionsCannotDelete = dict(code=40061, desc="主页方案不能删除")
    InvalidRatio = dict(code=40062, desc="不正确的比例值")
    HostAlreadyExists = dict(code=40063, desc="域名已被使用")
    ProductNotFound = dict(code=40064, desc="产品不存在")
    SkyboxNotFound = dict(code=40065, desc="天空盒不存在")
    SkyboxLibTypeNotExists = dict(code=40066, desc="天空盒类型不存在")
    ApplicationNotExist = dict(code=40067, desc="应用不存在")
    UserLoginFailed = dict(code=40068, desc="用户登录失败")
    AccountUpdateFailed = dict(code=40069, desc="更新账号信息失败")
    SceneNotFound = dict(code=40070, desc="场景不存在")
    ParentEntityNotFound = dict(code=40071, desc="父级渲染对象不存在")
    EntityNotFound = dict(code=40072, desc='渲染对象不存在')
    ComponentNotFound = dict(code=40073, desc='组件不存在')
    ResourceNotFound = dict(code=40074, desc='资源不存在')
    ParentResourceNotFound = dict(code=40075, desc='父级资源不存在')
    TemplateSceneNotFound = dict(code=40076, desc='模板场景不存在')
    MediaNotFound = dict(code=40077, desc='资源内容不存在')
    EventNotFound = dict(code=40078, desc='事件不存在')
    ParentEventNotFound = dict(code=40079, desc='父级事件不存在')
    ModelIsNotPublic = dict(code=40080, desc='模型处于非公开状态')
    ModelIsLocked = dict(code=40081, desc='模型已被加密，请输入密码')
    ModelPasswordWrong = dict(code=40082, desc='模型密码错误')
    CollectionNotFound = dict(code=40083, desc='集合不存在')
    CollectionIsNotPublic = dict(code=40084, desc='集合未公开')
    CollectionIsLocked = dict(code=40085, desc='集合已被加密，请输入密码')
    CollectionPasswordWrong = dict(code=40086, desc='集合密码错误')
    TokenIsWrong = dict(code=40087, desc='Token过期或无效')
    NotInvitedEmail = dict(code=40088, desc='非邀请邮箱')
    RoleNotFound = dict(code=40089, desc='角色不存在')
    CannotDeleteDefaultRole = dict(code=40090, desc='无法删除默认角色')
    CatalogNotFound = dict(code=40091, desc='3D图册不存在')
    CorpNotFound = dict(code=40092, desc='企业不存在')
    RoleNameExist = dict(code=40093, desc='角色名已存在')
    UserIsInTeam = dict(code=40094, desc='用户已被邀请或已加入团队')
    UserNotInSpace = dict(code=40095, desc='未加入任何团队')
    InvitedEmailHasBeenSent = dict(code=40096, desc='已经发送过邀请，请15分钟后再邀请')
    ResetEmailHasBeenSent = dict(code=40097, desc='60s内不能重复发送邮件')
    TagNotFound = dict(code=40098, desc='标签不存在')
    UpdateUserInfoFail = dict(code=40099, desc='更新用户信息失败')
    DomainIsExist = dict(code=40100, desc='域名已经存在')
    UserNotInCorp = dict(code=40101, desc='用户不属于此企业')
    SearchFieldNotExist = dict(code=40102, desc='搜索字段不存在')
    SortFieldNotExist = dict(code=40103, desc='排序字段不存在')
    PublishFailed = dict(code=40104, desc='发布失败，服务器处理出错')
    EmailFormatError = dict(code=40105, desc='邮箱格式不正确')
    InstanceNotExists = dict(code=40106, desc='不存在对象')
    GroupNotExists = dict(code=40109, desc='群组不存在')
    SpaceIsChanged = dict(code=40110, desc='已切换到其他团队，请关闭当前页面')
    NoCorpSpace = dict(code=40111, desc='用户无企业空间')
    TypeNotSupport = dict(code=40112, desc='不支持的资源类型')
    ButtonNotFound = dict(code=40113, desc='按钮不存在')
    ProjectNotFound = dict(code=40114, desc='项目不存在')
    SceneNotInSameProject = dict(code=40115, desc='场景不在同一个项目')
    EventIsExist = dict(code=40116, desc='事件已存在')
    AccountNotExist = dict(code=40117, desc='账号不存在')
    CaptchaAlreadyExpired = dict(code=40118, desc='验证码已过期')
    TooManyRequest = dict(code=40119, desc='请求过于频繁')
    UserNotInvited = dict(code=40120, desc='您未被邀请加入，请联系系统管理员')
    ModelNumberNotEnough = dict(code=40121, desc='模型数量不足')
    ProjectlNumberNotEnough = dict(code=40122, desc='项目数量不足')
    UserAlreadyInvited = dict(code=40123, desc='用户已被邀请')
    UrlAlreadyExpired = dict(code=40124, desc='重置链接已过期')
    NotBeInvited = dict(code=40125, desc='未收到邀请或链接地址错误')
    PasswordErrorOverTimes = dict(code=40127, desc='错误次数超过5次，请明天再尝试')
    SpaceIsRemoved = dict(code=40128, desc='团队权限被删除')
    NeedCaptcha = dict(code=40129, desc='首次登陆需要验证码')
    MacAlreadyExist = dict(code=40130, desc='终端地址已存在')
    BeKickedOutFromTeam = dict(code=40131, desc='您已被移出团队，请联系管理员')
    UnauthorizedOrTimeout = dict(code=40132, desc='未授权或授权过期')
    UIPackInvalid = dict(code=40133, desc='UI数据包无效')
    UIIconPackInvalid = dict(code=40134, desc='ui icon 包无效')
    OnlyOnePageNotDelete = dict(code=40134, desc='只剩一个页面，不能删除')
    IconPackMustZip = dict(code=40134, desc='icon 包必须是zip格式压缩包')
    GetStaticResourceDataError = dict(code=40135, desc='服务器获取发布数据错误')
    NotFoundScenePublishData = dict(code=40135, desc='找不到场景发布数据')
    CapacityNotEnough = dict(code=40135, desc='容量不足')
    PasswordWrong = dict(code=40136, desc='密码错误')

    # 运营后台
    NotAuthenticatedUser = dict(code=-40001, desc='未认证用户，请重新登录')
    NotVisitedPermission = dict(code=-40002, desc='你没有访问权限')
    NotUpdatedPermission = dict(code=-40003, desc='你没有修改权限')
    PermissionDenied = dict(code=-40004, desc='你没有对应的操作权限权限')
    GroupDeleteFailedForManagerExisted = dict(code=-40005, desc='当前群组里有成员，不能删除当前群组')
    GroupNameExisted = dict(code=-40006, desc='当前群组名已经存在')
    PasswordNotSame = dict(code=-40007, desc='两次输入的密码不一致')
    HasExistsAccount = dict(code=-40008, desc='当前账号已存在')

    # 重新刷新页面
    NotSpaceReFlashPage = dict(code=-50001, desc='不存在空间，请刷新')


    # 兼容下-10000错误码的提示
    AttributeNameAlreadyExist = dict(code=-10000, desc='该属性名已经存在')
    DuplicateAttributeValue = dict(code=-10000, desc='属性值重复')
    FileCopyFailure = dict(code=-10000, desc='不能将文件复制到自身或其子目录下')
    FileMoveFailure = dict(code=-10000, desc='不能将文件移动到自身或其子目录下')
    FolderHasDeleteFileMoveOrCopyFailure = dict(code=-10000, desc='包含转换失败的文件，不能移动或者复制，请先删除转换失败的文件')
    FolderAlreadyExist = dict(code=-10000, desc='已经存在该文件夹')
    ParentFolderNotExist = dict(code=-10000, desc='父文件不存在')

    # 开放平台
    InvalidSpaceUserApiToken = dict(code=-70001, desc='无效的空间用户API token')
    SpaceNotAuthApplication = dict(code=-70002, desc='该用户空间未授权该应用')
    NotInternalSpaceAppUser = dict(code=-70003, desc='不是内部应用空间用户')
    AlreadyAddApplication = dict(code=-70004, desc='您已经添加了该应用')
    ApplicationNotPublishOrDeleted = dict(code=-70005, desc='应用未发布或被删除')
    ApplicationNotBelowCurrentSpace = dict(code=-70005, desc='该内部应用不属于当前空间')
    OpenServerError = dict(code=-70100, desc='open server invoke fail')

    CheckRepeat = dict(code=-99006, desc="重复登录错误")  # cml--> 重复登录


@unique
class EnErrorCode(Enum):
    # 英文版
    # 系统级错误代码
    UserNotLogin = dict(code=-10007, desc="User not logged in")
    RequestParamInvalid = dict(code=-10008, desc="Request param invalid")

    # 接口级错误代码
    UserNameAlreadyExists = dict(code=40001, desc="Username is already registered")
    MaterialLibTypeNotExists = dict(code=40002, desc="Material lib type not exists")
    AccessPermissionDenied = dict(code=40003, desc="Access permission denied")
    SpaceNotExists = dict(code=40004, desc="Space does not exist")
    DstDirFolderNotExists = dict(code=40009, desc="Destination directory folder does not exist")
    DirFolderNotExists = dict(code=40010, desc="Current directory folder does not exist")
    TagAlreadyExists = dict(code=40018, desc="Tag already exist")
    TagNotExists = dict(code=40019, desc="Tag dose noet exist")
    TemplateNotExists = dict(code=40021, desc="Space custom field template does not exist")
    ModelNotExists = dict(code=40022, desc="Model does not exist")
    ProductionNotFound = dict(code=40027, desc="Production dose not exist")
    PageSizeOverflow = dict(code=40028, desc="Exceeding the limit")
    CabinetNotFound = dict(code=40029, desc="Cabinet does not exist")
    OperationPermissionDenied = dict(code=40030, desc="Permission denied")
    InvalidAccessToken = dict(code=40031, desc="invalid access token")
    UserNotFound = dict(code=40032, desc="User does not exist")
    ModelDescLengthOverflow = dict(code=40033, desc="Model description cannot exceed 100 characters")
    ModelNameLengthOverflow = dict(code=40034, desc="Model name cannot exceed 50 characters")
    CategoryNotExists = dict(code=40035, desc="Category does not exist")
    ModelGroupNotExists = dict(code=40036, desc="Model combination does not exist")
    ProductionNotExists = dict(code=40037, desc="Production dose not exist")
    JobNotFound = dict(code=40038, desc="Job dose not exist")
    JobFailed = dict(code=40039, desc="Job failure")
    MaterialNotFound = dict(code=40040, desc="Material not found")
    InvalidMobile = dict(code=40041, desc="Invalid mobile")
    InvalidOperationType = dict(code=40042, desc="Invalid operation type")
    SmsSendFailed = dict(code=40043, desc="Sms send failed")
    CaptchaError = dict(code=40044, desc="Captcha error")
    InvalidUsernameOrPassword = dict(code=40045, desc="Invalid account or password")
    PlatformNotFound = dict(code=40046, desc="platform not found")
    WechatResponseError = dict(code=40047, desc="Wechat response error")
    SpaceNameAlreadyExists = dict(code=40048, desc="Space name Already exist")
    InvalidEmail = dict(code=40049, desc="Invalid email")
    InvalidUploadPolicy = dict(code=40050, desc="Invalid upload policy")
    InvalidPassword = dict(code=40051, desc="Invalid password")
    MobileAlreadyExists = dict(code=40052, desc="Mobile number registered")
    InvalidCabinetName = dict(code=40053, desc="Invalid cabinet name")
    CabinetNameAlreadyExisted = dict(code=40054, desc="Cabinet already existed")
    InvalidCallback = dict(code=40055, desc="invalid callback token")
    CallCloudError = dict(code=40056, desc="Call cloud error")
    InvalidProductionName = dict(code=40057, desc="Invalid production name")
    ClientNotFound = dict(code=40059, desc="Client not found")
    ClientChannelNotExists = dict(code=40060, desc="Client channel not found")
    InvalidRatio = dict(code=40062, desc="Invalid ratio")
    HostAlreadyExists = dict(code=40063, desc="Domain name is already in use")
    ProductNotFound = dict(code=40064, desc="Product not found")
    SkyboxNotFound = dict(code=40065, desc="Skybox not found")
    SkyboxLibTypeNotExists = dict(code=40066, desc="Skybox lib type not found")
    ApplicationNotExist = dict(code=40067, desc="Application not found")
    UserLoginFailed = dict(code=40068, desc="User login failed")
    AccountUpdateFailed = dict(code=40069, desc="Account update failed")
    SceneNotFound = dict(code=40070, desc="Scene not found")
    ParentEntityNotFound = dict(code=40071, desc="Parent entity not found")
    EntityNotFound = dict(code=40072, desc='Entity not found')
    ComponentNotFound = dict(code=40073, desc='Component not found')
    ResourceNotFound = dict(code=40074, desc='Resource not found')
    ParentResourceNotFound = dict(code=40075, desc='Parent resource not found')
    TemplateSceneNotFound = dict(code=40076, desc='Template scene not found')
    MediaNotFound = dict(code=40077, desc='Media not found')
    EventNotFound = dict(code=40078, desc='Event not found')
    ParentEventNotFound = dict(code=40079, desc='Parent event not found')
    ModelIsNotPublic = dict(code=40080, desc='Model is not public')
    ModelIsLocked = dict(code=40081, desc='Model is locked, please imput password')
    ModelPasswordWrong = dict(code=40082, desc='Model password wrong')
    CollectionNotFound = dict(code=40083, desc='Collection not found')
    CollectionIsNotPublic = dict(code=40084, desc='Collection is not public')
    CollectionIsLocked = dict(code=40085, desc='Collection is locked, please imput password')
    CollectionPasswordWrong = dict(code=40086, desc='Collection password wrong')
    TokenIsWrong = dict(code=40087, desc='Invalid token')
    NotInvitedEmail = dict(code=40088, desc='Non invitation email')
    RoleNotFound = dict(code=40089, desc='Role not found')
    CannotDeleteDefaultRole = dict(code=40090, desc='Cannot delete default role')
    CorpNotFound = dict(code=40092, desc='Enterprise does not exist')
    RoleNameExist = dict(code=40093, desc='Role name already exists')
    UserIsInTeam = dict(code=40094, desc='User has been invited or joined the team')
    UserNotInSpace = dict(code=40095, desc='User not joined team')
    InvitedEmailHasBeenSent = dict(code=40096, desc='Invitation has been sent, please invite again in 15 minutes')
    ResetEmailHasBeenSent = dict(code=40097, desc='Can not send mail repeatedly within 60s')
    TagNotFound = dict(code=40098, desc='Label does not exist')
    UpdateUserInfoFail = dict(code=40099, desc='Failed to update user information')
    DomainIsExist = dict(code=40100, desc='Domain name already exists')
    UserNotInCorp = dict(code=40101, desc='User does not belong to this enterprise')
    SearchFieldNotExist = dict(code=40102, desc='Search field does not exist')
    SortFieldNotExist = dict(code=40103, desc='Sort field does not exist')
    PublishFailed = dict(code=40104, desc='Publishing failed, server processing error')
    EmailFormatError = dict(code=40105, desc='Invalid email format')
    InstanceNotExists = dict(code=40106, desc='Object does not exist')
    GroupNotExists = dict(code=40109, desc='Group not exist')
    SpaceIsChanged = dict(code=40110, desc='Space is changed，please close the current page')
    TypeNotSupport = dict(code=40112, desc='The type not support')
    ButtonNotFound = dict(code=40113, desc='Button not found')
    ProjectNotFound = dict(code=40114, desc='Project not found')
    SceneNotInSameProject = dict(code=40115, desc='Scene not in same project')
    EventIsExist = dict(code=40116, desc='Event is exist')
    AccountNotExist = dict(code=40117, desc='Account dose not exist')
    CaptchaAlreadyExpired = dict(code=40118, desc='Captcha already expired')
    TooManyRequest = dict(code=40119, desc='Too many requests')
    UserNotInvited = dict(code=40120, desc='You are not invited to join, please contact your system administrator')
    ModelNumberNotEnough = dict(code=40121, desc='Model number not enouth')
    ProjectlNumberNotEnough = dict(code=40122, desc='Project number not enouth')
    UserAlreadyInvited = dict(code=40123, desc='User already invited')
    UrlAlreadyExpired = dict(code=40124, desc='Url already expired')
    NotBeInvited = dict(code=40125, desc='No invitation received or wrong link address')
    MacLimited = dict(code=40126, desc='The current device cannot enter the target space')
    PasswordErrorOverTimes = dict(code=40127, desc='Password more than 5 errors, please try again tomorrow')
    SpaceIsRemoved = dict(code=40128, desc='Space permissions deleted')
    NeedCaptcha = dict(code=40129, desc='First login requires verification code')
    MacAlreadyExist = dict(code=40130, desc='Terminal address already exists')
    BeKickedOutFromTeam = dict(code=40131, desc='You have been removed from the space. Please contact your system administrator')

    # 运营后台
    NotAuthenticatedUser = dict(code=-40001, desc='未认证用户，请重新登录')
    NotVisitedPermission = dict(code=-40002, desc='你没有访问权限')
    NotUpdatedPermission = dict(code=-40003, desc='你没有修改权限')
    PermissionDenied = dict(code=-40004, desc='你没有对应的操作权限权限')
    GroupDeleteFailedForManagerExisted = dict(code=-40005, desc='当前群组里有成员，不能删除当前群组')
    GroupNameExisted = dict(code=-40006, desc='当前群组名已经存在')
    PasswordNotSame = dict(code=-40007, desc='两次输入的密码不一致')
    HasExistsAccount = dict(code=-40008, desc='当前账号已存在')

    # 重新刷新页面
    NotSpaceReFlashPage = dict(code=-50001, desc='不存在空间，请刷新')
    NotInSpace = dict(code=-50001, desc='团队权限被删除')
    ClientMacLimited = dict(code=-50002, desc='终端无法访问')

    # 兼容下-10000错误码的提示
    AttributeNameAlreadyExist = dict(code=-10000, desc='Attribute name already eist')
    DuplicateAttributeValue = dict(code=-10000, desc='Duplicate attribute value')
    FileCopyFailure = dict(code=-10000, desc='Files cannot be copied to themselves or their subdirectories')
    FileMoveFailure = dict(code=-10000, desc='Files cannot be move to themselves or their subdirectories')
    DirHasDeleteFileMoveOrCopyFailure = dict(code=-10000,
                                             desc='The file containing the conversion failure cannot be moved or copied. Please delete the conversion failure file first')
    FolderAlreadyExist = dict(code=-10000, desc='Folder already exist')
    ParentFolderNotExist = dict(code=-10000, desc='Parent folder not exist')


    # 开放平台
    InvalidSpaceUserApiToken = dict(code=-70001, desc='无效的空间用户API token')
    SpaceNotAuthApplication = dict(code=-70002, desc='空间未授权该应用')
    NotInternalSpaceAppUser = dict(code=-70003, desc='不是内部应用空间用户')
    OpenServerError = dict(code=-70100, desc='open server invoke fail')

    CheckRepeat = dict(code=-99006, desc="Duplication error")  # cml--> 重复登录


@unique
class TipsCode(Enum):
    CheckUserName = dict(code=-99001, message="用户名错误")  # 用户名检查相关
    CheckMobile = dict(code=-99002, message="手机号码错误")  # 手机号码检查相关
    CheckPassword = dict(code=-99003, message="密码错误")  # 密码检查相关
    CheckParameter = dict(code=-99004, message="参数错误")  # 参数检查相关
    CheckCaptcha = dict(code=-99005, message="验证码错误")
    CheckRepeat = dict(code=-99006, message="重复登录错误")  # cml--> 重复登录

    PasswordNotSame = dict(code=40103, message='密码不一致')  # 密码不一致
    AccountAlreadyExists = dict(code=40104, message='已存在账户')  # 已存在账户
    GroupNotExists = dict(code=40105, message='群组不存在')  # 群组不存在
    InstanceNotExists = dict(code=40106, message="不存在对象")  # 不存在对象
    HasJoinGroup = dict(code=40106, message="已经加入该组")  # 已经加入该组
    RequiredParam = dict(code=40107, message="必填参数")  # 必填参数
    integerOutOfRange = dict(code=40108, message="整型数太大")  # 整型数太大
    ModelNotPublished = dict(code=40109, message='模型未发布')

    InviteNoPriceSet = dict(code=-30001, message="该空间当前没有购买任何套餐")
    InvitePriceSetOuttime = dict(code=-30002, message="该空间套餐已过期")
    InviteNoPriceSetItem = dict(code=-30003, message="该空间套餐不含邀请项")
    InviteOutPriceSetItemLimit = dict(code=-30004, message="该空间容量已满，请升级套餐")

    MeetingAlreadyOver = dict(code=-40001, message='会议已经结束')
    OutOfPeopleNum = dict(code=-40002, message='会议参与人数上限为10人，现在已经达到10人')
    ParticipantAlreadyDeleted = dict(code=-40003, message='您被会议管理人员移除会议，请联系会议发起人')
    NotInMeeting = dict(code=-40004, message='您未参加过此会议')
    MaxTwoReviewScene = dict(code=-40005, message='最多同时支持两个场景评审')
    MeetingNotOverYet = dict(code=-40006, message='会议尚未结束')


@unique
class EnTipsCode(Enum):
    CheckUserName = dict(code=-99001, message="Account error")  # 用户名检查相关
    CheckMobile = dict(code=-99002, message="Wrong mobile number")  # 手机号码检查相关
    CheckPassword = dict(code=-99003, message="Password error")  # 密码检查相关
    CheckParameter = dict(code=-99004, message="Parem error")  # 参数检查相关
    CheckCaptcha = dict(code=-99005, message="Captcha error")
    CheckRepeat = dict(code=-99006, message="Duplication error")  # cml--> 重复登录

    PasswordNotSame = dict(code=40103, message='Passwords are inconsistent')  # 密码不一致
    AccountAlreadyExists = dict(code=40104, message='Account already exist')  # 已存在账户
    GroupNotExists = dict(code=40105, message='Group does not exist')  # 群组不存在
    InstanceNotExists = dict(code=40106, message="Object does not exist")  # 不存在对象
    HasJoinGroup = dict(code=40106, message="Already joined the group")  # 已经加入该组
    RequiredParam = dict(code=40107, message="Required param")  # 必填参数
    integerOutOfRange = dict(code=40108, message="Integer too large")  # 整型数太大
    ModelNotPublished = dict(code=40109, message='Model not published')

    InviteNoPriceSet = dict(code=-30001, message="No packages are currently purchased for this space")
    InvitePriceSetOuttime = dict(code=-30002, message="The space package has expired")
    InviteNoPriceSetItem = dict(code=-30003, message="The space package does not include invitations")
    InviteOutPriceSetItemLimit = dict(code=-30004, message="This space is full, please upgrade the package")

    MeetingAlreadyOver = dict(code=-40001, message='The meeting is over')
    OutOfPeopleNum = dict(code=-40002, message='The maximum number of participants in the meeting is 10, now it has reached 10')
    ParticipantAlreadyDeleted = dict(code=-40003, message='You have been removed from the meeting by the meeting management. Please contact the meeting sponsor')
    NotInMeeting = dict(code=-40004, message='You have not attended this meeting')
    MaxTwoReviewScene = dict(code=-40005, message='Up to two scenario reviews are supported at the same time')
    MeetingNotOverYet = dict(code=-40006, message='The meeting is not over')


class WebsocketCode:

    def __init__(self, **kwargs):
        username = kwargs.get('username')
        data = kwargs.get('data', {})
        subject_name = kwargs.get('subject_name')
        object_name = kwargs.get('object_name')
        team_name = kwargs.get('team_name')
        self.JoinTwoMeeting = dict(code=-1001,
                                   message='您在其他地方加入了会议',
                                   data=dict(content=dict(zh='您在其他地方加入了会议',
                                                          en='You have joined another meeting')))
        self.DeletedParticipant = dict(code=-1002,
                                       message='{username}被移出会议'.format(username=username),
                                       data=dict(username=username,
                                                 content=dict(zh='被移出会议',
                                                              en='is removed from the meeting'),
                                                 participant_uid=data.get('uid')))
        self.ParticipantExit = dict(code=-1003,
                                    message='{username}已退出会议'.format(username=username),
                                    data=dict(username=username,
                                              content=dict(zh='已退出会议',
                                                           en='has left the meeting')))
        self.BeKickedOutFromTeam = dict(code=-1004,
                                        message='你已被管理员移出 {team_name} 团队'.format(team_name=team_name),
                                        data=dict(team_name=team_name,
                                                  content=dict(zh='你已被管理员移出团队',
                                                               en='You have been removed from the team by the administrator')))
        # self.DataUpdated = dict(code=1000, message='data updated', data=data)
        self.MasterChanged = dict(code=1001,
                                  message='{subject_name}已将主控权移交给{object_name}'.format(subject_name=subject_name, object_name=object_name),
                                  data=dict(subject_name=subject_name,
                                            object_name=object_name,
                                            content=dict(zh='已将主控权移交给',
                                                         en='has transferred the mastership to'),
                                            master_uid=data.get('master_uid')))
        self.JoinMeeting = dict(code=1002,
                                message='{username}已加入会议'.format(username=username),
                                data=dict(username=username,
                                          content=dict(zh='已加入会议',
                                                       en='has joined the meeting')))
        self.CreateMarker = dict(code=1003, message='create marker', data=data)
        self.DeleteMarker = dict(code=1004, message='delete marker', data=data)
        self.UpdateMakrer = dict(code=1005, message='update makrer', data=data)
        self.CreateReviewScene = dict(code=1006, message='create review scene', data=data)
        self.DeleteReviewScene = dict(code=1007, message='delete review scene', data=data)
        self.EndMeeting = dict(code=1008,
                               message='您已经结束会议',
                               data=dict(content=dict(zh='您已经结束会议',
                                                      en='You have ended the meeting')))
        self.MeetingAlreadyOver = dict(code=1009,
                                       message='会议已经结束',
                                       data=dict(content=dict(zh='会议已经结束',
                                                              en='The meeting is over')))

if __name__ == '__main__':
    print(ErrorCode.BeKickedOutFromTeam.value)


#!/usr/bin/python3.6.8+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2020-12-2
@desc: ...
"""
import os
from pydantic import Field, AnyUrl
from yzcore.default_settings import DefaultSetting, get_configer


# yaml格式解析器
# conf = get_configer('yaml', import_path=os.path.dirname(__file__))

# ini格式解析器
conf = get_configer('ini', import_path=os.path.dirname(__file__))


class Settings(DefaultSetting):
    PROJECT_NAME: str = 'MyProject'
    DEBUG: bool = True
    API_V1_STR: str = "/api/v1"
    SECRET_KEY: str = "{}"
    BASE_URL: str = "http://127.0.0.1:8000"

    # postgres数据库的URI
    DB_URI: str = Field('http://test.test.com/', env="DB_URI")
    src_path: str = os.path.abspath(os.path.dirname(__file__))  # 代码绝对路径
    ID_URL: AnyUrl = "http://127.0.0.1:8000/api/v1"


if __name__ == '__main__':
    from yzcore.default_settings import default_setting
    print(default_setting.ID_URL)
    print(default_setting.DB_URI)



#!/usr/bin/python3.6.8+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2020-10-20
@desc: 对阿里云oss的封装，依赖oss2

配置文件：
    [oss_manager]
    access_key_id = XXXXX
    access_key_secret = XXXXX
    endpoint = oss-cn-shenzhen.aliyuncs.com
    # internal_endpoint = oss-cn-shenzhen-internal.aliyuncs.com
    bucket_name = bucket_name
    image_domain = internal.image.realibox.com
    asset_domain = internal.asset.realibox.com
    expire_time = 30
    cache_path = /tmp/xxxx/cache/
"""

import os
import shutil
import json
import base64
import hmac
import datetime
import hashlib
import urllib
from enum import Enum
try:
    import oss2
except:
    oss2 = None

from . import OssManagerBase

__all__ = [
    "OssManager", "OssManagerError"
]


OssManagerError = type("OssManagerError", (ValueError,), {})


# class ACL(Enum):
#     private = oss2.BUCKET_ACL_PRIVATE
#     onlyread = oss2.BUCKET_ACL_PUBLIC_READ
#     readwrite = oss2.BUCKET_ACL_PUBLIC_READ_WRITE


class OssManager(OssManagerBase):
    """
    使用示例:
        >>> from . import OssManager
        >>> oss_conf = dict(
        ...     access_key_id="LTAIxxxxxxxxxxx",
        ...     access_key_secret="Cep4Mxxxxxxxxxxxxxxxxxxxx",
        ...     endpoint="oss-cn-shenzhen.aliyuncs.com",
        ...     # endpoint="oss-cn-shenzhen-internal.aliyuncs.com",
        ...     bucket_name="xxxx-local",
        ...     cache_path="/tmp/xxxx/fm/cache"
        ... )

        >>> oss = OssManager(**oss_conf)
        >>> oss.upload("/home/zhangw/Work/模型文件/狼.fbx", "test/狗.fbx")
        >>> oss.download("test/狗.fbx")
    """

    acl_type = {
        "private": oss2.BUCKET_ACL_PRIVATE,
        "onlyread": oss2.BUCKET_ACL_PUBLIC_READ,
        "readwrite": oss2.BUCKET_ACL_PUBLIC_READ_WRITE,
    }
    # 存储类型
    storage_cls = {
        "standard": oss2.BUCKET_STORAGE_CLASS_STANDARD,          # 标准类型
        "ia": oss2.BUCKET_STORAGE_CLASS_IA,                      # 低频访问类型
        "archive": oss2.BUCKET_STORAGE_CLASS_ARCHIVE,            # 归档类型
        "cold_archive": oss2.BUCKET_STORAGE_CLASS_COLD_ARCHIVE,  # 冷归档类型
    }
    # 冗余类型
    redundancy_type = {
        "lrs": oss2.BUCKET_DATA_REDUNDANCY_TYPE_LRS,    # 本地冗余
        "zrs": oss2.BUCKET_DATA_REDUNDANCY_TYPE_ZRS,    # 同城冗余（跨机房）
    }

    def __init__(self, *args, **kwargs):
        super(OssManager, self).__init__(*args, **kwargs)

    def __init(self, bucket_name=None):
        """初始化对象"""
        if oss2 is None:
            raise ImportError("'oss2' must be installed to use OssManager")
        if not any((self.endpoint, self.cname)):
            raise AttributeError(
                "One of 'endpoint' and 'cname' must not be None.")

        self.auth = oss2.Auth(self.access_key_id, self.access_key_secret)

        # 如果cname存在，则使用自定义域名初始化
        self.endpoint = self.cname if self.cname else self.endpoint
        is_cname = True if self.cname else False
        self.bucket_name = bucket_name if bucket_name else self.bucket_name
        self.bucket = oss2.Bucket(
            self.auth, self.endpoint, self.bucket_name, is_cname=is_cname
        )

        if self.cache_path:
            try:
                os.makedirs(self.cache_path)
            except OSError:
                pass
            # make_dir(self.cache_path)

    def reload_oss(self, **kwargs):
        """重新加载oss配置"""
        self.access_key_id = kwargs.get("access_key_id")
        self.access_key_secret = kwargs.get("access_key_secret")
        self.bucket_name = kwargs.get("bucket_name")
        self.endpoint = kwargs.get("endpoint")
        self.__init()

    def create_bucket(self, bucket_name=None,
                      acl_type='private',
                      storage_type='standard',
                      redundancy_type='zrs'):
        self.__init(bucket_name=bucket_name)
        permission = self.acl_type.get(acl_type)
        config = oss2.models.BucketCreateConfig(
            storage_class=self.storage_cls.get(storage_type),
            data_redundancy_type=self.redundancy_type.get(redundancy_type)
        )
        return self.bucket.create_bucket(permission, input=config)

    def iter_buckets(self, prefix='', marker='', max_keys=100, max_retries=None):
        """
        :param prefix: 只列举匹配该前缀的Bucket
        :param marker: 分页符。只列举Bucket名字典序在此之后的Bucket
        :param max_keys: 每次调用 `list_buckets` 时的max_keys参数。注意迭代器返回的数目可能会大于该值。
        :param max_retries:
        :return:
        """
        if not hasattr(self, 'service'):
            self.service = oss2.Service(self.auth, self.endpoint)

        return oss2.BucketIterator(
            self.service, prefix=prefix, marker=marker,
            max_keys=max_keys, max_retries=max_retries)

    def list_buckets(self, prefix='', marker='', max_keys=100, params=None):
        """根据前缀罗列用户的Bucket。

        :param str prefix: 只罗列Bucket名为该前缀的Bucket，空串表示罗列所有的Bucket
        :param str marker: 分页标志。首次调用传空串，后续使用返回值中的next_marker
        :param int max_keys: 每次调用最多返回的Bucket数目
        :param dict params: list操作参数，传入'tag-key','tag-value'对结果进行过滤

        :return: 罗列的结果
        :rtype: oss2.models.ListBucketsResult
        """
        if not hasattr(self, 'service'):
            self.service = oss2.Service(self.auth, self.endpoint)
        return self.service.list_buckets(
            prefix=prefix, marker=marker, max_keys=max_keys, params=params)

    def is_exist_bucket(self):
        """判断存储空间是否存在"""
        try:
            self.bucket.get_bucket_info()
        except oss2.exceptions.NoSuchBucket:
            return False
        except:
            raise
        return True

    def delete_bucket(self, bucket_name=None):
        """删除bucket"""
        try:
            resp = self.bucket.delete_bucket()
            if resp.status < 300:
                return True
            elif resp.status == 404:
                return False
        except:
            import traceback
            print(traceback.format_exc())

    # def encrypt_bucket(self):
    #     """设置Bucket加密"""
    #     # 创建Bucket加密配置，以AES256加密为例。
    #     rule = oss2.models.ServerSideEncryptionRule()
    #     rule.sse_algorithm = oss2.SERVER_SIDE_ENCRYPTION_AES256
    #     # 设置KMS密钥ID，加密方式为KMS可设置此项。
    #     # 如需使用指定的密钥加密，需输入指定的CMK ID；
    #     # 若使用OSS托管的CMK进行加密，此项为空。使用AES256进行加密时，此项必须为空。
    #     rule.kms_master_keyid = ""
    #
    #     # 设置Bucket加密。
    #     result = self.bucket.put_bucket_encryption(rule)
    #     # 查看HTTP返回码。
    #     print('http response code:', result.status)
    #     return result
    #
    # def delete_encrypt_bucket(self):
    #     # 删除Bucket加密配置。
    #     result = self.bucket.delete_bucket_encryption()
    #     # 查看HTTP返回码。
    #     print('http status:', result.status)
    #     return result

    def get_sign_url(self, key, expire=10):
        return self.bucket.sign_url("GET", key, expire)

    def post_sign_url(self, key, expire=10):
        return self.bucket.sign_url("POST", key, expire)

    def download(self, key, local_name=None,
                 is_return_obj=False,
                 progress_callback=None, process=None):
        """
        下载oss文件

        :param key:
        :param local_name:
        :param process:
        :param load_stream_in_memory:
            is_stream = True:
                >>> result = self.download('readme.txt', load_stream_in_memory=True)
                >>> print(result.read())
                'hello world'
            is_stream = False:
                >>> result = self.download('readme.txt', '/tmp/cache/readme.txt')
                >>> print(result)
                '/tmp/cache/readme.txt'
        :return:
        """
        if not local_name:
            local_name = os.path.abspath(
                os.path.join(self.cache_path, key)
            )
        make_dir(os.path.dirname(local_name))
        if is_return_obj:
            return self.bucket.get_object(key, process=process)
        else:
            self.bucket.get_object_to_file(key, local_name, process=process)
            return local_name

    def upload(self, filepath, key=None, num_threads=2):
        """上传oss文件"""
        if key is None:
            key = filepath.split('/')[-1]
        headers = None
        if filepath.endswith(".dds"):
            headers = dict()
            headers["Content-Type"] = "application/octet-stream"

        result = oss2.resumable_upload(
            self.bucket, key, filepath,
            headers=headers,
            num_threads=num_threads,
        )
        # 返回下载链接
        if not any((self.image_domain, self.asset_domain)):
            return True, result.resp.response.url
        return True, self.get_file_url(filepath, key)

    # def get_policy(
    #         self,
    #         filepath,
    #         callback_url,
    #         callback_data=None,
    #         callback_content_type="application/json"):
    #     """
    #     授权给第三方上传
    #
    #     :param filepath:
    #     :param callback_url:
    #     :param callback_data: 需要回传的参数
    #     :param callback_content_type: 回调时的Content-Type
    #            "application/json"
    #            "application/x-www-form-urlencoded"
    #
    #     :return:
    #     """
    #     params = urllib.parse.urlencode(
    #         dict(data=json.dumps(callback_data)))
    #     policy_encode = self._get_policy_encode(filepath)
    #     sign = self.get_signature(policy_encode)
    #
    #     callback_dict = dict()
    #     callback_dict["callbackUrl"] = callback_url
    #     callback_dict["callbackBody"] = (
    #         "filepath=${object}&size=${size}&mime_type=${mimeType}"
    #         "&img_height=${imageInfo.height}&img_width=${imageInfo.width}"
    #         "&img_format=${imageInfo.format}&" + params
    #     )
    #     callback_dict["callbackBodyType"] = callback_content_type
    #
    #     callback_param = json.dumps(callback_dict).strip().encode()
    #     base64_callback_body = base64.b64encode(callback_param)
    #
    #     return dict(
    #         accessid=self.access_key_id,
    #         host=f"{self.scheme}://{self.bucket_name}.{self.endpoint}",
    #         policy=policy_encode.decode(),
    #         signature=sign,
    #         dir=filepath,
    #         callback=base64_callback_body.decode(),
    #     )
    #
    # def _get_policy_encode(self, filepath):
    #     expire_time = datetime.datetime.now() + datetime.timedelta(
    #         seconds=self.policy_expire_time
    #     )
    #     policy_dict = dict(
    #         expiration=expire_time.isoformat() + "Z",
    #         conditions=[
    #             ["starts-with", "$key", filepath],                    # 指定值开始
    #             # ["eq", "$success_action_redirect", "public-read"],  # 精确匹配
    #             # ["content-length-range", 1, 1024*1024*1024]         # 对象大小限制
    #         ],
    #     )
    #     policy = json.dumps(policy_dict).strip().encode()
    #     return base64.b64encode(policy)
    #
    # def get_signature(self, policy_encode):
    #     """
    #     获取签名
    #
    #     :param policy_encode:
    #     :return:
    #     """
    #     h = hmac.new(
    #         self.access_key_secret.encode("utf-8"), policy_encode, hashlib.sha1
    #     )
    #     sign_result = base64.encodebytes(h.digest()).strip()
    #     return sign_result.decode()

    def update_file_headers(self, key, headers):
        self.bucket.update_object_meta(key, headers)





def make_dir(dir_path):
    """新建目录"""
    try:
        os.makedirs(dir_path)
    except OSError:
        pass


def copy_file(src, dst):
    """拷贝文件"""
    dst_dir = os.path.dirname(dst)
    make_dir(dst_dir)
    shutil.copy(src, dst)


if __name__ == '__main__':
    kwargs = dict(
        access_key_id='',
        access_key_secret='',
        endpoint='oss-cn-shenzhen.aliyuncs.com',
        bucket_name='',
    )
    oss_obj = OssManager(**kwargs)
    file_name = '/Users/edz/realibox/base-all/base/src/core/request/beta_gangnam_style.fbx'
    # remote_name = 'cmltest.fbx'

    # 上传
    result_obj = oss_obj.upload(file_name)
    print(result_obj)
    """
    http://realicloud-local.oss-cn-shenzhen.aliyuncs.com/beta_gangnam_style.fbx
    """

    """
    # result:
    {
        'resp': <oss2.http.Response object at 0x1071ddc50>, 
        'status': 200, 
        'headers': {
            'Server': 'AliyunOSS', 
            'Date': 'Tue, 20 Oct 2020 01:22:34 GMT', 
            'Content-Length': '0', 
            'Connection': 'keep-alive', 
            'x-oss-request-id': '5F8E3BDAFEC931303087D9D9', 
            'ETag': '"D41D8CD98F00B204E9800998ECF8427E"', 
            'x-oss-hash-crc64ecma': '0', 
            'Content-MD5': '1B2M2Y8AsgTpgAmY7PhCfg==', 
            'x-oss-server-time': '63'
        }, 
        'request_id': '5F8E3BDAFEC931303087D9D9', 
        'versionid': None, 
        'delete_marker': None, 
        'etag': 'D41D8CD98F00B204E9800998ECF8427E', 
        'crc': 0
    }
    
    # result.resp:
    {
        'response': <Response [200]>, 
        'status': 200, 
        'headers': {
            'Server': 'AliyunOSS', 
            'Date': 'Tue, 20 Oct 2020 02:31:03 GMT', 
            'Content-Length': '0', 
            'Connection': 'keep-alive', 
            'x-oss-request-id': '5F8E4BE7FEC93130387B8D5B', 
            'ETag': '"D41D8CD98F00B204E9800998ECF8427E"', 
            'x-oss-hash-crc64ecma': '0', 
            'Content-MD5': '1B2M2Y8AsgTpgAmY7PhCfg==', 
            'x-oss-server-time': '49'
        }, 
        'request_id': '5F8E4BE7FEC93130387B8D5B', 
        '_Response__all_read': True
    }
    
    # result.resp.response:
    {
        '_content': False, 
        '_content_consumed': True, 
        '_next': None, 
        'status_code': 200, 
        'headers': {
            'Server': 'AliyunOSS', 
            'Date': 'Tue, 20 Oct 2020 02:32:13 GMT', 
            'Content-Length': '0', 
            'Connection': 'keep-alive', 
            'x-oss-request-id': '5F8E4C2D4D5A2B3339F164B7', 
            'ETag': '"D41D8CD98F00B204E9800998ECF8427E"', 
            'x-oss-hash-crc64ecma': '0', 
            'Content-MD5': '1B2M2Y8AsgTpgAmY7PhCfg==', 
            'x-oss-server-time': '18'
        }, 
        'raw': <urllib3.response.HTTPResponse object at 0x104254a10>, 
        'url': 'http://haier-mdcp-private.oss-cn-qingdao.aliyuncs.com/cmltest.fbx', 
        'encoding': None, 
        'history': [], 
        'reason': 'OK', 
        'cookies': <RequestsCookieJar[]>, 
        'elapsed': datetime.timedelta(microseconds=250406), 
        'request': <PreparedRequest [PUT]>, 
        'connection': <requests.adapters.HTTPAdapter object at 0x1041fb710>
    }
    
    """

    # 下载
    # res = oss_obj.download(remote_name)
    # print(res)


#!/usr/bin/python3.7+
# -*- coding:utf-8 -*-
"""
@auth: cml
@date: 2020-9-
@desc: ...
"""
import time
import subprocess
from starlette.applications import Starlette
from starlette.responses import JSONResponse
from starlette.routing import Route
from starlette.background import BackgroundTask


# subprocess.check_output

async def signup(request):
    data = await request.json()
    username = data['username']
    email = data['email']
    task = BackgroundTask(send_welcome_email, to_address=email)
    print("---->", task)
    message = {'status': 'Signup successful'}
    return JSONResponse(message, background=task)

async def send_welcome_email(to_address):
    """"""
    time.sleep(5)
    print("====>", to_address)
    


routes = [
    Route('/user/signup', endpoint=signup, methods=['POST'])
]

app = Starlette(routes=routes)